You are viewing a plain text version of this content. The canonical link for it is here.
Posted to batik-commits@xmlgraphics.apache.org by ca...@apache.org on 2005/07/12 04:06:00 UTC

svn commit: r215909 [13/13] - in /xmlgraphics/batik/branches/svg12: ./ contrib/charts/xml/ contrib/charts/xsl/ contrib/fonts/gladiator/svg/ contrib/jsvg/ contrib/tiledTranscoder/ resources/org/apache/batik/apps/svgbrowser/resources/ resources/org/apach...

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/MemoryLeakTest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/MemoryLeakTest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/MemoryLeakTest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/MemoryLeakTest.java Mon Jul 11 19:05:44 2005
@@ -34,7 +34,7 @@
  *
  * Complete Class Desc
  *
- * @author <a href="mailto:deweese@apache.org>l449433</a>
+ * @author <a href="mailto:deweese@apache.org">l449433</a>
  * @version $Id$
  */
 public abstract class MemoryLeakTest  extends AbstractTest {

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/MemoryLeakTestValidator.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/MemoryLeakTestValidator.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/MemoryLeakTestValidator.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/MemoryLeakTestValidator.java Mon Jul 11 19:05:44 2005
@@ -24,7 +24,7 @@
  *
  * Complete Class Desc
  *
- * @author <a href="mailto:deweese@apache.org>l449433</a>
+ * @author <a href="mailto:deweese@apache.org">l449433</a>
  * @version $Id$
  */
 public class MemoryLeakTestValidator extends MemoryLeakTest {

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/TestSuiteReport.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/TestSuiteReport.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/TestSuiteReport.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/TestSuiteReport.java Mon Jul 11 19:05:44 2005
@@ -1,52 +1,18 @@
 /*
-
- ============================================================================
-                   The Apache Software License, Version 1.1
- ============================================================================
-
- Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
-
- Redistribution and use in source and binary forms, with or without modifica-
- tion, are permitted provided that the following conditions are met:
-
- 1. Redistributions of  source code must  retain the above copyright  notice,
-    this list of conditions and the following disclaimer.
-
- 2. Redistributions in binary form must reproduce the above copyright notice,
-    this list of conditions and the following disclaimer in the documentation
-    and/or other materials provided with the distribution.
-
- 3. The end-user documentation included with the redistribution, if any, must
-    include  the following  acknowledgment:  "This product includes  software
-    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
-    Alternately, this  acknowledgment may  appear in the software itself,  if
-    and wherever such third-party acknowledgments normally appear.
-
- 4. The names "Batik" and  "Apache Software Foundation" must  not  be
-    used to  endorse or promote  products derived from  this software without
-    prior written permission. For written permission, please contact
-    apache@apache.org.
-
- 5. Products  derived from this software may not  be called "Apache", nor may
-    "Apache" appear  in their name,  without prior written permission  of the
-    Apache Software Foundation.
-
- THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
- INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
- FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
- APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
- INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
- DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
- OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
- ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
- (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
- THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
- This software  consists of voluntary contributions made  by many individuals
- on  behalf of the Apache Software  Foundation. For more  information on the
- Apache Software Foundation, please see <http://www.apache.org/>.
-
-*/
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 package org.apache.batik.test;
 

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/BERenderingTest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/BERenderingTest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/BERenderingTest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/BERenderingTest.java Mon Jul 11 19:05:44 2005
@@ -21,7 +21,7 @@
  * Preconfigured test for SVG files under the xml-batik/../beSuite
  * directory.
  *
- * @author <a href="vhardy@apache.org">Vincent Hardy</a>
+ * @author <a href="mailto:vhardy@apache.org">Vincent Hardy</a>
  * @version $Id$
  */
 public class BERenderingTest extends PreconfiguredRenderingTest {

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/JSVGRenderingAccuracyTest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/JSVGRenderingAccuracyTest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/JSVGRenderingAccuracyTest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/JSVGRenderingAccuracyTest.java Mon Jul 11 19:05:44 2005
@@ -43,7 +43,7 @@
  *
  * Complete Class Desc
  *
- * @author <a href="mailto:deweese@apache.org>l449433</a>
+ * @author <a href="mailto:deweese@apache.org">l449433</a>
  * @version $Id$
  */
 public class JSVGRenderingAccuracyTest extends SamplesRenderingTest 

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/PreconfiguredRenderingTest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/PreconfiguredRenderingTest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/PreconfiguredRenderingTest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/PreconfiguredRenderingTest.java Mon Jul 11 19:05:44 2005
@@ -23,7 +23,7 @@
  * Convenience class for creating a SVGRenderingAccuracyTest with predefined
  * rules for the various configuration parameters.
  *
- * @author <a href="vhardy@apache.org">Vincent Hardy</a>
+ * @author <a href="mailto:vhardy@apache.org">Vincent Hardy</a>
  * @version $Id$
  */
 public abstract class PreconfiguredRenderingTest extends SVGRenderingAccuracyTest {

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SVGOnLoadExceptionTest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SVGOnLoadExceptionTest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SVGTextContentRenderingAccuracyTest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SVGTextContentRenderingAccuracyTest.java Mon Jul 11 19:05:44 2005
@@ -1,52 +1,18 @@
 /*
-
- ============================================================================
-                   The Apache Software License, Version 1.1
- ============================================================================
-
- Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
-
- Redistribution and use in source and binary forms, with or without modifica-
- tion, are permitted provided that the following conditions are met:
-
- 1. Redistributions of  source code must  retain the above copyright  notice,
-    this list of conditions and the following disclaimer.
-
- 2. Redistributions in binary form must reproduce the above copyright notice,
-    this list of conditions and the following disclaimer in the documentation
-    and/or other materials provided with the distribution.
-
- 3. The end-user documentation included with the redistribution, if any, must
-    include  the following  acknowledgment:  "This product includes  software
-    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
-    Alternately, this  acknowledgment may  appear in the software itself,  if
-    and wherever such third-party acknowledgments normally appear.
-
- 4. The names "Batik" and  "Apache Software Foundation" must  not  be
-    used to  endorse or promote  products derived from  this software without
-    prior written permission. For written permission, please contact
-    apache@apache.org.
-
- 5. Products  derived from this software may not  be called "Apache", nor may
-    "Apache" appear  in their name,  without prior written permission  of the
-    Apache Software Foundation.
-
- THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
- INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
- FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
- APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
- INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
- DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
- OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
- ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
- (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
- THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
- This software  consists of voluntary contributions made  by many individuals
- on  behalf of the Apache Software  Foundation. For more  information on the
- Apache Software Foundation, please see <http://www.apache.org/>.
-
-*/
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 package org.apache.batik.test.svg;
 

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SamplesRenderingTest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SamplesRenderingTest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SamplesRenderingTest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SamplesRenderingTest.java Mon Jul 11 19:05:44 2005
@@ -20,7 +20,7 @@
 /**
  * Preconfigured test for SVG files under the xml-batik directory.
  *
- * @author <a href="vhardy@apache.org">Vincent Hardy</a>
+ * @author <a href="mailto:vhardy@apache.org">Vincent Hardy</a>
  * @version $Id$
  */
 public class SamplesRenderingTest extends PreconfiguredRenderingTest {

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/util/ImageCompareTest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/util/ImageCompareTest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/util/ImageCompareTest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/util/ImageCompareTest.java Mon Jul 11 19:05:44 2005
@@ -1,52 +1,18 @@
 /*
-
- ============================================================================
-                   The Apache Software License, Version 1.1
- ============================================================================
-
- Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
-
- Redistribution and use in source and binary forms, with or without modifica-
- tion, are permitted provided that the following conditions are met:
-
- 1. Redistributions of  source code must  retain the above copyright  notice,
-    this list of conditions and the following disclaimer.
-
- 2. Redistributions in binary form must reproduce the above copyright notice,
-    this list of conditions and the following disclaimer in the documentation
-    and/or other materials provided with the distribution.
-
- 3. The end-user documentation included with the redistribution, if any, must
-    include  the following  acknowledgment:  "This product includes  software
-    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
-    Alternately, this  acknowledgment may  appear in the software itself,  if
-    and wherever such third-party acknowledgments normally appear.
-
- 4. The names "Batik" and  "Apache Software Foundation" must  not  be
-    used to  endorse or promote  products derived from  this software without
-    prior written permission. For written permission, please contact
-    apache@apache.org.
-
- 5. Products  derived from this software may not  be called "Apache", nor may
-    "Apache" appear  in their name,  without prior written permission  of the
-    Apache Software Foundation.
-
- THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
- INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
- FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
- APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
- INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
- DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
- OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
- ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
- (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
- THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
- This software  consists of voluntary contributions made  by many individuals
- on  behalf of the Apache Software  Foundation. For more  information on the
- Apache Software Foundation, please see <http://www.apache.org/>.
-
-*/
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 package org.apache.batik.test.util;
 
@@ -78,7 +44,7 @@
  * two images are identical. It fails otherwise, producing a report
  * describing why the two images are different.
  *
- * @author <a href="vhardy@apache.org">Vincent Hardy</a>
+ * @author <a href="mailto:vhardy@apache.org">Vincent Hardy</a>
  * @version $Id$
  */
 public class ImageCompareTest extends AbstractTest {

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/xml/XTSConstants.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/xml/XTSConstants.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/xml/XTSConstants.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/xml/XTSConstants.java Mon Jul 11 19:05:44 2005
@@ -1,52 +1,18 @@
 /*
-
- ============================================================================
-                   The Apache Software License, Version 1.1
- ============================================================================
-
- Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
-
- Redistribution and use in source and binary forms, with or without modifica-
- tion, are permitted provided that the following conditions are met:
-
- 1. Redistributions of  source code must  retain the above copyright  notice,
-    this list of conditions and the following disclaimer.
-
- 2. Redistributions in binary form must reproduce the above copyright notice,
-    this list of conditions and the following disclaimer in the documentation
-    and/or other materials provided with the distribution.
-
- 3. The end-user documentation included with the redistribution, if any, must
-    include  the following  acknowledgment:  "This product includes  software
-    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
-    Alternately, this  acknowledgment may  appear in the software itself,  if
-    and wherever such third-party acknowledgments normally appear.
-
- 4. The names "Batik" and  "Apache Software Foundation" must  not  be
-    used to  endorse or promote  products derived from  this software without
-    prior written permission. For written permission, please contact
-    apache@apache.org.
-
- 5. Products  derived from this software may not  be called "Apache", nor may
-    "Apache" appear  in their name,  without prior written permission  of the
-    Apache Software Foundation.
-
- THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
- INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
- FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
- APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
- INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
- DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
- OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
- ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
- (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
- THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
- This software  consists of voluntary contributions made  by many individuals
- on  behalf of the Apache Software  Foundation. For more  information on the
- Apache Software Foundation, please see <http://www.apache.org/>.
-
-*/
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 package org.apache.batik.test.xml;
 

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/transcoder/TranscoderInputTest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/transcoder/TranscoderInputTest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/transcoder/TranscoderInputTest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/transcoder/TranscoderInputTest.java Mon Jul 11 19:05:44 2005
@@ -1,52 +1,18 @@
 /*
-
- ============================================================================
-                   The Apache Software License, Version 1.1
- ============================================================================
-
- Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
-
- Redistribution and use in source and binary forms, with or without modifica-
- tion, are permitted provided that the following conditions are met:
-
- 1. Redistributions of  source code must  retain the above copyright  notice,
-    this list of conditions and the following disclaimer.
-
- 2. Redistributions in binary form must reproduce the above copyright notice,
-    this list of conditions and the following disclaimer in the documentation
-    and/or other materials provided with the distribution.
-
- 3. The end-user documentation included with the redistribution, if any, must
-    include  the following  acknowledgment:  "This product includes  software
-    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
-    Alternately, this  acknowledgment may  appear in the software itself,  if
-    and wherever such third-party acknowledgments normally appear.
-
- 4. The names "Batik" and  "Apache Software Foundation" must  not  be
-    used to  endorse or promote  products derived from  this software without
-    prior written permission. For written permission, please contact
-    apache@apache.org.
-
- 5. Products  derived from this software may not  be called "Apache", nor may
-    "Apache" appear  in their name,  without prior written permission  of the
-    Apache Software Foundation.
-
- THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
- INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
- FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
- APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
- INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
- DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
- OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
- ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
- (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
- THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
- This software  consists of voluntary contributions made  by many individuals
- on  behalf of the Apache Software  Foundation. For more  information on the
- Apache Software Foundation, please see <http://www.apache.org/>.
-
-*/
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 package org.apache.batik.transcoder;
 

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/transcoder/image/URITest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/transcoder/image/URITest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/transcoder/image/URITest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/transcoder/image/URITest.java Mon Jul 11 19:05:44 2005
@@ -1,52 +1,18 @@
 /*
-
- ============================================================================
-                   The Apache Software License, Version 1.1
- ============================================================================
-
- Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
-
- Redistribution and use in source and binary forms, with or without modifica-
- tion, are permitted provided that the following conditions are met:
-
- 1. Redistributions of  source code must  retain the above copyright  notice,
-    this list of conditions and the following disclaimer.
-
- 2. Redistributions in binary form must reproduce the above copyright notice,
-    this list of conditions and the following disclaimer in the documentation
-    and/or other materials provided with the distribution.
-
- 3. The end-user documentation included with the redistribution, if any, must
-    include  the following  acknowledgment:  "This product includes  software
-    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
-    Alternately, this  acknowledgment may  appear in the software itself,  if
-    and wherever such third-party acknowledgments normally appear.
-
- 4. The names "Batik" and  "Apache Software Foundation" must  not  be
-    used to  endorse or promote  products derived from  this software without
-    prior written permission. For written permission, please contact
-    apache@apache.org.
-
- 5. Products  derived from this software may not  be called "Apache", nor may
-    "Apache" appear  in their name,  without prior written permission  of the
-    Apache Software Foundation.
-
- THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
- INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
- FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
- APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
- INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
- DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
- OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
- ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
- (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
- THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
- This software  consists of voluntary contributions made  by many individuals
- on  behalf of the Apache Software  Foundation. For more  information on the
- Apache Software Foundation, please see <http://www.apache.org/>.
-
-*/
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 package org.apache.batik.transcoder.image;
 

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/util/RunnableQueueTest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/util/RunnableQueueTest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/util/RunnableQueueTest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/util/RunnableQueueTest.java Mon Jul 11 19:05:44 2005
@@ -37,9 +37,12 @@
      * @param sync     Should requests be made synchronously (from
      *                 different threads).
      */
-    public RunnableQueueTest(int nThreads, boolean sync) {
+    public RunnableQueueTest(int nThreads) {
         this.nThreads = nThreads;
     }
+    public RunnableQueueTest(Integer nThreads) {
+        this((nThreads==null)?10:nThreads.intValue());
+    }
         
         /**
          * Returns this Test's name
@@ -203,7 +206,7 @@
     }
 
     public static void main(String []args) {
-        RunnableQueueTest rqt = new RunnableQueueTest(20, false);
+        RunnableQueueTest rqt = new RunnableQueueTest(20);
         try {
             rqt.runImpl();
         } catch (Exception e) {

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/util/ThreadPounder.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/util/ThreadPounder.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/util/ThreadPounder.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/util/ThreadPounder.java Mon Jul 11 19:05:44 2005
@@ -1,52 +1,18 @@
 /*
-
- ============================================================================
-                   The Apache Software License, Version 1.1
- ============================================================================
-
- Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
-
- Redistribution and use in source and binary forms, with or without modifica-
- tion, are permitted provided that the following conditions are met:
-
- 1. Redistributions of  source code must  retain the above copyright  notice,
-    this list of conditions and the following disclaimer.
-
- 2. Redistributions in binary form must reproduce the above copyright notice,
-    this list of conditions and the following disclaimer in the documentation
-    and/or other materials provided with the distribution.
-
- 3. The end-user documentation included with the redistribution, if any, must
-    include  the following  acknowledgment:  "This product includes  software
-    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
-    Alternately, this  acknowledgment may  appear in the software itself,  if
-    and wherever such third-party acknowledgments normally appear.
-
- 4. The names "Batik" and  "Apache Software Foundation" must  not  be
-    used to  endorse or promote  products derived from  this software without
-    prior written permission. For written permission, please contact
-    apache@apache.org.
-
- 5. Products  derived from this software may not  be called "Apache", nor may
-    "Apache" appear  in their name,  without prior written permission  of the
-    Apache Software Foundation.
-
- THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
- INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
- FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
- APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
- INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
- DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
- OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
- ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
- (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
- THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
- This software  consists of voluntary contributions made  by many individuals
- on  behalf of the Apache Software  Foundation. For more  information on the
- Apache Software Foundation, please see <http://www.apache.org/>.
-
-*/
+ * Copyright 1999-2003,2005 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 package org.apache.batik.util;
 

Modified: xmlgraphics/batik/branches/svg12/xdocs/book.xml
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/book.xml?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/book.xml (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/book.xml Mon Jul 11 19:05:44 2005
@@ -2,7 +2,7 @@
 
 <!--
 
-   Copyright 2000,2002-2004  The Apache Software Foundation 
+   Copyright 2000-2005  The Apache Software Foundation 
 
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
@@ -24,11 +24,11 @@
 <!-- version $Id$        -->
 <!-- ========================================================================= -->
 
-<book title="Apache Batik documentation" copyright="2000-2002 The Apache Software Foundation">
+<book title="Apache Batik documentation" copyright="2000-2005 The Apache Software Foundation">
     <!-- ======================= -->
     <!-- Home                    -->
     <!-- ======================= -->
-    <external                    label="Home"                      href="http://xml.apache.org/"/>
+    <external                    label="Home"                      href="http://xmlgraphics.apache.org/"/>
     <separator/>
 
     <!-- ======================= -->
@@ -36,6 +36,7 @@
     <!-- ======================= -->
     <page id="index"              label="Overview"                 source="index.xml"/>
     <faqs id="faqs"               label="FAQ"                      source="faq.xml"/>
+    <external                     label="Wiki"                     href="http://wiki.apache.org/xmlgraphics-batik/FrontPage" />
     <page id="license"            label="License"                  source="license.xml"/>
     <external                     label="Download"                 href="http://www.apache.org/dyn/closer.cgi/xml/batik" />
     <page id="install"            label="Install"                  source="installing.xml"/>
@@ -90,7 +91,7 @@
     <!-- ======================= -->
     <!-- Admin / Status          -->
     <!-- ======================= -->
-    <page id="cvs"                label="CVS Repository"           source="cvs.xml"/>
+    <page id="svn"                label="SVN Repository"           source="svn.xml"/>
     <external                     label="Bug Database"             href="http://issues.apache.org/bugzilla"/>
     <separator/>
     <page id="status"             label="Status"                   source="status.xml" />

Modified: xmlgraphics/batik/branches/svg12/xdocs/faq.xml
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/faq.xml?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/faq.xml (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/faq.xml Mon Jul 11 19:05:44 2005
@@ -1,7 +1,7 @@
 <?xml version="1.0"?>
 <!--
 
-   Copyright 2000-2004  The Apache Software Foundation 
+   Copyright 2000-2005  The Apache Software Foundation 
 
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
@@ -314,11 +314,11 @@
         </p>
         <p>
         For direct participation, we suggest you to subscribe to the
-        <link href="http://xml.apache.org/mail.html">Batik mailing
+        <link href="http://xmlgraphics.apache.org/mail.html">Batik mailing
         list</link> (follow the link for information on how to
         subscribe and to access the mail list archives), and to
         checkout the <link
-        href="http://cvs.apache.org/viewcvs.cgi/xml-batik/">latest
+		href="http://svn.apache.org/viewcvs.cgi/xmlgraphics/batik/">latest
         code</link>.
         </p>
     </answer>
@@ -510,7 +510,7 @@
     <answer>
         <p>
         You can submit bug fixes and patches to the <link
-        href="mailto:batik-dev@xml.apache.org">Batik developers</link>
+        href="mailto:batik-dev@xmlgraphics.apache.org">Batik developers</link>
         mailing list and you can enter bugs in <link
         href="http://issues.apache.org/bugzilla/">Bugzilla</link>.
         </p>
@@ -761,11 +761,12 @@
 </faq>
 <faq>
     <question>
-    How do I checkout the latest CVS version of Batik?
+    How do I checkout the latest SVN version of Batik?
     </question> 
     <answer>
       <p>You just have to follow the instructions posted on the
-      <link href="http://xml.apache.org/cvs.html">XML Apache CVS page</link>.
+      <link href="http://xmlgraphics.apache.org/repo.html">Apache 
+      XML Graphics code repository page</link>.
       </p>
     </answer>
 </faq>

Modified: xmlgraphics/batik/branches/svg12/xdocs/images/splash.png
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/images/splash.png?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
Binary files - no diff available.

Modified: xmlgraphics/batik/branches/svg12/xdocs/images/splash.svg
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/images/splash.svg?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/images/splash.svg (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/images/splash.svg Mon Jul 11 19:05:44 2005
@@ -1,21 +1,4 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<!--
-
-   Copyright 2002-2004  The Apache Software Foundation 
-
-   Licensed under the Apache License, Version 2.0 (the "License");
-   you may not use this file except in compliance with the License.
-   You may obtain a copy of the License at
-
-       http://www.apache.org/licenses/LICENSE-2.0
-
-   Unless required by applicable law or agreed to in writing, software
-   distributed under the License is distributed on an "AS IS" BASIS,
-   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-   See the License for the specific language governing permissions and
-   limitations under the License.
-
--->
 <svg xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 492 150" height="150" width="492" id="body">
 <title>Batik URL card for JavaOne 2001</title>
 <defs>
@@ -53,7 +36,7 @@
 <use height="131" width="114" x="46" y="11" xlink:href="#Batik_Squiggle" filter="url(#dropShadow)"/>
 <g filter="url(#dropShadow)" fill="white" text-anchor="middle" font-size="75" font-family="'20th Century Font', 'Futura XBlk BT'" id="topText">
 <text y="95" x="246">
-<tspan font-size="95">batik</tspan>1.5.1</text>
+<tspan font-size="95">batik</tspan>1.6</text>
 <text y="130" x="246" font-size="17">http://xml.apache.org/batik</text>
 </g>
 </g>

Modified: xmlgraphics/batik/branches/svg12/xdocs/images/splash.xsl
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/images/splash.xsl?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/images/splash.xsl (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/images/splash.xsl Mon Jul 11 19:05:44 2005
@@ -1,20 +1,29 @@
 <?xml version="1.0" standalone="no"?>
-<!-- ========================================================================= -->
-<!-- Copyright (C) The Apache Software Foundation. All rights reserved.        -->
-<!--                                                                           -->
-<!-- This software is published under the terms of the Apache Software License -->
-<!-- version 1.1, a copy of which has been included with this distribution in  -->
-<!-- the LICENSE file.                                                         -->
-<!-- ========================================================================= -->
+<!--
 
-<!-- ========================================================================= -->
-<!-- This simple XSL stylesheet is used to automatically generate the splash   -->
-<!-- screen for the documentation and the Squiggle browser. See the 'splash'   -->
-<!-- target in build.xml.                                                      -->
-<!--                                                                           -->
-<!-- @author vincent.hardy@eng.sun.com                                         -->
-<!-- @version $Id$      -->
-<!-- ========================================================================= -->
+   Copyright 2002,2004-2005  The Apache Software Foundation 
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+-->
+<!-- ====================================================================== -->
+<!-- This simple XSL stylesheet is used to automatically generate the       -->
+<!-- splash screen for the documentation and the Squiggle browser. See the  -->
+<!-- 'splash' target in build.xml.                                          -->
+<!--                                                                        -->
+<!-- @author vincent.hardy@eng.sun.com                                      -->
+<!-- @version $Id$       -->
+<!-- ====================================================================== -->
 
 <xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"  
                               xmlns:xlink="http://www.w3.org/1999/xlink"

Modified: xmlgraphics/batik/branches/svg12/xdocs/installing.xml
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/installing.xml?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/installing.xml (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/installing.xml Mon Jul 11 19:05:44 2005
@@ -83,7 +83,7 @@
             distribution</em> contains a complete snapshot of
           the Batik source code, documentation, regression tools
           and utilities as well as the script for building
-          Batik. That distribution is a snapshot of the CVS
+          Batik. That distribution is a snapshot of the SVN
           repository. This is the recommended distribution for
           developers who want to dive into the code and
           understand how Batik can be integrated in their
@@ -95,20 +95,21 @@
       </ul>
 
       <p>We make nightly copies of the source tree available from the
-      <link href="http://cvs.apache.org/builds/xml-batik">Apache
+      <link href="http://svn.apache.org/builds/xml-batik">Apache
       build</link> server. These builds represent the current state of
       development and may or may not be as stable as releases.
       There are two types of distributions provided.</p>
       <ul>
-        <li><strong>batik-cvs-</strong><em>date</em><strong>.zip</strong>
-          (e.g., <code>batik-cvs-03-09-26.zip</code>)<br/> 
+        <li><strong>batik-svn-</strong><em>date</em><strong>.zip</strong>
+          or <strong>batik-cvs-</strong><em>date</em><strong>.zip</strong>
+          (e.g., <code>batik-svn-03-09-26.zip</code>)<br/> 
 
-          This contains a complete copy of the CVS tree, including
-          support for running <link href="test.html">regard</link>
+          This contains a complete copy of the SVN (or old CVS) tree,
+          including support for running <link href="test.html">regard</link>
           Batik's regression testing utility.  In particular this
           includes all the reference images for testing.  Developers
           are encouraged to get these or better use <link
-          href="cvs.html">CVS</link> directly.
+          href="svn.html">SVN</link> directly.
         </li>
         <li><strong>batik-src-</strong><em>date</em><strong>.zip</strong>
           (e.g., <code>batik-src-03-09-26.zip</code>)<br/> 

Modified: xmlgraphics/batik/branches/svg12/xdocs/mail-lists.xml
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/mail-lists.xml?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/mail-lists.xml (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/mail-lists.xml Mon Jul 11 19:05:44 2005
@@ -4,7 +4,7 @@
 
 <!--
 
-   Copyright 2001-2004  The Apache Software Foundation 
+   Copyright 2001-2005  The Apache Software Foundation 
 
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
@@ -39,16 +39,22 @@
     mailing list, please first look at the following resources in this order:</p>
    <ol>
     <li><link href="faqs.html">Batik FAQs</link></li>
-    <li><link href="http://mail-archives.apache.org/eyebrowse/SummarizeList?listName=batik-users@xml.apache.org">Batik-Users Archive</link></li>
-    <li><link href="http://mail-archives.apache.org/eyebrowse/SummarizeList?listName=batik-dev@xml.apache.org">Batik-Dev Archive</link></li>
+    <li>Batik-Users Archive (check links below)</li>
+    <li>Batik-Dev Archive (check links below)</li>
    </ol>
   </s1>
 
   <s1 title="Batik Users">
-   <p><link href="mailto:batik-users-subscribe@xml.apache.org">Subscribe</link>
-      <link href="mailto:batik-users-unsubscribe@xml.apache.org">Unsubscribe</link>
-      <link href="http://mail-archives.apache.org/eyebrowse/SummarizeList?listName=batik-users@xml.apache.org">Archive</link>
+   <p><link href="mailto:batik-users-subscribe@xmlgraphics.apache.org">Subscribe</link>
+      <link href="mailto:batik-users-unsubscribe@xmlgraphics.apache.org">Unsubscribe</link>
    </p>
+   
+   <p><strong>Archives:</strong></p>
+   <ul>
+    <li><link href="http://mail-archives.eu.apache.org/mod_mbox/xmlgraphics-batik-users/">mod_mbox Archives</link></li>
+    <li><link href="http://xmlgraphics.apache.org/mail/batik-users/">gzipped mbox files</link></li>
+    <li><link href="http://mail-archives.apache.org/eyebrowse/SummarizeList?listName=batik-users@xml.apache.org">Eyebrowse Archive</link> (currently broken)</li>
+   </ul>
 
    <p>The general Batik list, for problems using Batik, bug reports... 
    This is not an appropriate list for general SVG questions, you might try
@@ -63,11 +69,16 @@
   </s1>
 
   <s1 title="Batik Dev">
-   <p><link href="mailto:batik-dev-subscribe@xml.apache.org">Subscribe</link>
-      <link href="mailto:batik-dev-unsubscribe@xml.apache.org">Unsubscribe</link>
-      <link href="http://mail-archives.apache.org/eyebrowse/SummarizeList?listName=batik-dev@xml.apache.org">Archive</link>
+   <p><link href="mailto:batik-dev-subscribe@xmlgraphics.apache.org">Subscribe</link>
+      <link href="mailto:batik-dev-unsubscribe@xmlgraphics.apache.org">Unsubscribe</link>
    </p>
 
+   <p><strong>Archives:</strong></p>
+   <ul>
+    <li><link href="http://mail-archives.eu.apache.org/mod_mbox/xmlgraphics-batik-dev/">mod_mbox Archives</link></li>
+    <li><link href="http://xmlgraphics.apache.org/mail/batik-dev/">gzipped mbox files</link></li>
+    <li><link href="http://mail-archives.apache.org/eyebrowse/SummarizeList?listName=batik-dev@xml.apache.org">Eyebrowse Archive</link> (currently broken)</li>
+   </ul>
    <p>This list is for developers <strong>working on</strong> or wanting to work on
     Batik itself (not developers merely working <strong>with</strong> Batik),
     for patches to Batik to be posted,...

Modified: xmlgraphics/batik/branches/svg12/xdocs/pr.xml
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/pr.xml?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/pr.xml (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/pr.xml Mon Jul 11 19:05:44 2005
@@ -3,7 +3,7 @@
 
 <!--
 
-   Copyright 2000-2002  The Apache Software Foundation 
+   Copyright 2000-2002,2004-2005  The Apache Software Foundation 
 
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
@@ -189,7 +189,7 @@
 representation capabilities.</p>
  
 <p>The Batik Project encourages participation through its mailing list:
-<link href="http://xml.apache.org/mail.html">http://xml.apache.org/mail.html</link></p>
+<link href="http://xmlgraphics.apache.org/mail.html">http://xmlgraphics.apache.org/mail.html</link></p>
  
 <p>For more information about the Batik project please see
 <link href="http://xml.apache.org/batik/">http://xml.apache.org/batik/</link></p>

Modified: xmlgraphics/batik/branches/svg12/xdocs/site-book.xml
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/site-book.xml?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/site-book.xml (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/site-book.xml Mon Jul 11 19:05:44 2005
@@ -2,7 +2,7 @@
 
 <!--
 
-   Copyright 2000-2004  The Apache Software Foundation 
+   Copyright 2000-2005  The Apache Software Foundation 
 
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
@@ -24,11 +24,11 @@
 <!-- version $Id$        -->
 <!-- ========================================================================= -->
 
-<book title="Apache Batik documentation" copyright="2000-2002 The Apache Software Foundation">
+<book title="Apache Batik documentation" copyright="2000-2005 The Apache Software Foundation">
     <!-- ======================= -->
     <!-- Home                    -->
     <!-- ======================= -->
-    <external                    label="Home"                      href="http://xml.apache.org/"/>
+    <external                    label="Home"                      href="http://xmlgraphics.apache.org/"/>
     <separator/>
 
     <!-- ======================= -->
@@ -36,6 +36,7 @@
     <!-- ======================= -->
     <page id="index"              label="Overview"                 source="index.xml"/>
     <faqs id="faqs"               label="FAQ"                      source="faq.xml"/>
+    <external                     label="Wiki"                     href="http://wiki.apache.org/xmlgraphics-batik/FrontPage" />
     <page id="license"            label="License"                  source="license.xml"/>
     <external                     label="Download"                 href="http://www.apache.org/dyn/closer.cgi/xml/batik" />
     <page id="install"            label="Install"                  source="installing.xml"/>
@@ -90,7 +91,7 @@
     <!-- ======================= -->
     <!-- Admin / Status          -->
     <!-- ======================= -->
-    <page id="cvs"                label="CVS Repository"           source="cvs.xml"/>
+    <page id="svn"                label="SVN Repository"           source="svn.xml"/>
     <external                     label="Bug Database"             href="http://issues.apache.org/bugzilla"/>
     <separator/>
     <page id="status"             label="Status"                   source="status.xml" />

Modified: xmlgraphics/batik/branches/svg12/xdocs/svggen.xml
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/svggen.xml?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/svggen.xml (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/svggen.xml Mon Jul 11 19:05:44 2005
@@ -244,7 +244,7 @@
   <source>
 
 SVGGeneratorContext ctx = SVGGeneratorContext.createDefault(myFactory);
-ImageHandler ihandler = new ImageHandlerPNGEncoder("res/images", null);
+GenericImageHandler ihandler = new ImageHandlerPNGEncoder("res/images", null);
 ctx.setImageHandler(ihandler);
 SVGGraphics2D g2d = new SVGGraphics2D(ctx, false);
   </source>
@@ -306,7 +306,7 @@
   </p>
   <source>
 
-public class StyleSheetStyleHandler {
+public class StyleSheetStyleHandler implements StyleHandler {
     private CDATASection styleSheet;
     // Build the handler with a reference to the StyleSheet section
     public StyleSheetStyleHandler(CDATASection styleSheet) {
@@ -345,7 +345,7 @@
 // use the g2d to dump drawings (component.paint(g2d))
 
 // add a style sheet to the definition section
-Element root = g2d.getRoot();
+SVGSVGElement root = (SVGSVGElement)g2d.getRoot();
 Element defs = root.getElementById(SVGSyntax.ID_PREFIX_GENERIC_DEFS);
 Element style = myFactory.createElementNS(SVGSyntax.SVG_NAMESPACE_URI, 
                                           SVGSyntax.SVG_STYLE_TAG);
@@ -377,7 +377,7 @@
           Element grad = generatorCtx.getDOMFactory().
                createElementNS(SVGSyntax.SVG_NAMESPACE_URI, 
                                SVGSyntax.SVG_LINEAR_GRADIENT_TAG);
-          grad.setAttributeNS(null, SVGSyntax.SVG_ID_ATTRIBUTE, ref);
+          grad.setAttributeNS(null, SVGSyntax.SVG_ID_ATTRIBUTE, id);
           grad.setAttributeNS(null, 
 	                      SVGSyntax.SVG_GRADIENT_UNITS_ATTRIBUTE, 
 	                      SVGSyntax.SVG_USER_SPACE_ON_USE_VALUE);

Propchange: xmlgraphics/batik/branches/svg12/xdocs/svn.xml
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: xmlgraphics/batik/branches/svg12/xdocs/svn.xml
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Modified: xmlgraphics/batik/branches/svg12/xdocs/testInfrastructure.xml
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/testInfrastructure.xml?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/testInfrastructure.xml (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/testInfrastructure.xml Mon Jul 11 19:05:44 2005
@@ -369,7 +369,7 @@
         <p><em>Daily usage</em></p>
         <p />
         <p>Once the intial set-up has been done, you can use regard by simply updating your 
-        CVS copy, including the test-references. If no change occurs, your test will keep passing
+        SVN copy, including the test-references. If no change occurs, your test will keep passing
         with your reference images. If a test fails (e.g., if someone checks in a new reference
         image from a platform different than the one you are using, you will have to check if it is
         because of system specific reasons or if there is a bigger problem.</p>
@@ -452,4 +452,4 @@
         </s1>
 
     </body>
-</document>
\ No newline at end of file
+</document>

Modified: xmlgraphics/batik/branches/svg12/xdocs/whoAreWe.xml
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/xdocs/whoAreWe.xml?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================
--- xmlgraphics/batik/branches/svg12/xdocs/whoAreWe.xml (original)
+++ xmlgraphics/batik/branches/svg12/xdocs/whoAreWe.xml Mon Jul 11 19:05:44 2005
@@ -1,18 +1,28 @@
 <?xml version="1.0"?>
 <!DOCTYPE document SYSTEM "./dtd/document-v10.dtd">
 
-<!-- ========================================================================= -->
-<!-- Copyright (C) The Apache Software Foundation. All rights reserved.        -->
-<!--                                                                           -->
-<!-- This software is published under the terms of the Apache Software License -->
-<!-- version 1.1, a copy of which has been included with this distribution in  -->
-<!-- the LICENSE file.                                                         -->
-<!-- ========================================================================= -->
-
-<!-- ========================================================================= -->
-<!-- author stephane@hillion.org                                               -->
-<!-- version $Id$ -->
-<!-- ========================================================================= -->
+<!--
+
+   Copyright 2000-2003,2005  The Apache Software Foundation 
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+-->
+
+<!-- ====================================================================== -->
+<!-- author stephane@hillion.org                                            -->
+<!-- version $Id$    -->
+<!-- ====================================================================== -->
 <document>
     <header>
         <title>Contributors</title>
@@ -182,7 +192,7 @@
         <p>
         In addition, <link href="mailto:James.Davidson@eng.sun.com">James Davidson</link>
         and <link href="mailto:stefano@apache.org">Stefano Mazzochi</link> , two Apache veterans who helped the
-        Batik team start the project at Apache, also have commit access to the CVS repository.
+        Batik team start the project at Apache, also have commit access to the SVN repository.
         </p>        
       </s1>
--- xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SVGOnLoadExceptionTest.java (original)
+++ xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SVGOnLoadExceptionTest.java Mon Jul 11 19:05:44 2005
@@ -22,6 +22,7 @@
 import java.net.URL;
 
 import org.w3c.dom.Document;
+import org.w3c.dom.Element;
 
 import org.apache.batik.bridge.BaseScriptingEnvironment;
 import org.apache.batik.bridge.BridgeContext;
@@ -87,6 +88,11 @@
  */
 public class SVGOnLoadExceptionTest extends AbstractTest {
     /**
+     * Value for the script having successfully run.
+     */
+    public static final String RAN = "ran";
+
+    /**
      * Error when the expected exception did not occur
      */
     public static final String ERROR_EXCEPTION_DID_NOT_OCCUR
@@ -107,6 +113,12 @@
         = "SVGOnLoadExceptionTest.error.unexpected.error.code";
 
     /**
+     * Error when the script does not run as expected.
+     */
+    public static final String ERROR_SCRIPT_DID_NOT_RUN
+        = "SVGOnLoadExceptionTest.error.script.did.not.run";
+
+    /**
      * Entry describing the unexpected exception
      */
     public static final String ENTRY_KEY_UNEXPECTED_EXCEPTION
@@ -131,6 +143,12 @@
         = "SVGOnLoadExceptionTest.entry.key.expected.exception";
 
     /**
+     * Entry describing the unexpected exception
+     */
+    public static final String ENTRY_KEY_UNEXPECTED_RESULT
+        = "SVGOnLoadExceptionTest.entry.key.unexpected.result";
+
+    /**
      * Value used to disable error code check on BridgeExceptions
      */
     public static final String ERROR_CODE_NO_CHECK
@@ -354,16 +372,18 @@
                 permissions.add(new FilePermission(fileName, "read"));
                 permissions.add(new RuntimePermission("accessDeclaredMembers"));
 
-                ProtectionDomain domain = new ProtectionDomain(null, permissions);
-                AccessControlContext ctx = new AccessControlContext
-                    (new ProtectionDomain[] {domain});
+                ProtectionDomain domain;
+                AccessControlContext ctx;
+                domain = new ProtectionDomain(null, permissions);
+                ctx = new AccessControlContext(new ProtectionDomain[]{domain});
 
                 try {
-                    return (TestReport)AccessController.doPrivileged(new PrivilegedExceptionAction() {
-                            public Object run() throws Exception {
-                                return testImpl();
-                            }
-                        }, ctx);
+                    return (TestReport)AccessController.doPrivileged
+                        (new PrivilegedExceptionAction() {
+                                public Object run() throws Exception {
+                                    return testImpl();
+                                }
+                            }, ctx);
                 } catch (PrivilegedActionException pae) {
                     throw pae.getException();
                 }
@@ -390,6 +410,7 @@
         try {
             doc = f.createDocument(svgURL);
         } catch(Exception e){
+            e.printStackTrace();
             return handleException(e);
         } 
         
@@ -423,12 +444,26 @@
         } 
         
         //
-        // If we got here, it means that the expected exception did not
-        // happen. Report an error
-        //
-        TestReport report = reportError(ERROR_EXCEPTION_DID_NOT_OCCUR);
-        report.addDescriptionEntry(ENTRY_KEY_EXPECTED_EXCEPTION,
-                                   expectedExceptionClass);
+        // If we got here, it means that an exception did not
+        // happen. Check if this is expected.
+        TestReport report = null;
+        if (expectedExceptionClass == null) {
+            // No error was expected then check that the script ran.
+            Element elem = doc.getElementById("testResult");
+            String s = elem.getAttributeNS(null, "result");
+            if (RAN.equals(s)) {
+                report = reportSuccess();
+            } else {
+                report = reportError(ERROR_SCRIPT_DID_NOT_RUN);
+                report.addDescriptionEntry(ENTRY_KEY_UNEXPECTED_RESULT,
+                                           s);
+            }
+        }
+        if (report == null) {
+            report = reportError(ERROR_EXCEPTION_DID_NOT_OCCUR);
+            report.addDescriptionEntry(ENTRY_KEY_EXPECTED_EXCEPTION,
+                                       expectedExceptionClass);
+        }
         return report;
     }
 
@@ -512,11 +547,11 @@
                     result = new RelaxedScriptSecurity(scriptType,
                                                      scriptURL,
                                                      docURL);
-                } else if ("DOCUMENT".equals(resourceOrigin)) {
+                } else if ("DOCUMENT".equals(scriptOrigin)) {
                     result = new DefaultScriptSecurity(scriptType,
                                                      scriptURL,
                                                      docURL);
-                } else if ("EMBEDED".equals(resourceOrigin)) {
+                } else if ("EMBEDED".equals(scriptOrigin)) {
                     result = new EmbededScriptSecurity(scriptType,
                                                      scriptURL,
                                                      docURL);

Modified: xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SVGTextContentRenderingAccuracyTest.java
URL: http://svn.apache.org/viewcvs/xmlgraphics/batik/branches/svg12/test-sources/org/apache/batik/test/svg/SVGTextContentRenderingAccuracyTest.java?rev=215909&r1=215908&r2=215909&view=diff
==============================================================================